# Table of Contents

- [configuring-microsoft-teams-channel](<./configuring-microsoft-teams-channel.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring the Microsoft Teams Channel](<./Configuring-the-Microsoft-Teams-Channel.md>)
  - [Workspace Notifications](<./Configuring-the-Microsoft-Teams-Channel/Workspace-Notifications.md>)
  - [Fact Sheet Update Details](<./Configuring-the-Microsoft-Teams-Channel/Fact-Sheet-Update-Details.md>)
